@@ -58,7 +58,7 @@ fn list_themes_with_syntaxes<W: Write>(
 
     let themes = {
         let mut m = load_bat_themes()?.themes;
-        m.extend(ThemeSet::load_defaults().themes.into_iter());
+        m.extend(ThemeSet::load_defaults().themes);
         let mut v: Vec<_> = m.into_iter().collect();
         v.sort_by(|l, r| l.0.cmp(&r.0));
         v
@@ -1089,6 +1089,8 @@ where
                 | "nspawn" | "path" | "service" | "scope" | "slice" | "socket" | "swap" | "target"
                 | "timer",
             ) => Some("INI"),
+            Some("sarif" | "jsonl") => Some("JSON"),
+            Some("ron") => Some("Rust"),
             _ => None,
         };
 
@@ -1097,6 +1099,7 @@ where
             Some(".clang-format" | "fish_history") => Some("YAML"),
             Some("nginx.conf" | "mime.types") => Some("nginx"),
             Some("httpd.conf") => Some("Apache Conf"),
+            Some("Containerfile") => Some("Dockerfile"),
             _ => None,
         });
 
